"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DatePicker = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _designparams = require("../designparams");

var _Typography = require("../Typography");

var _Button = require("../Button");

var _practicalReactComponentsIcons = require("practical-react-components-icons");

var _theme = require("../theme");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var DatePickerWrapper = _styledComponents.default.div.withConfig({
  displayName: "DatePicker__DatePickerWrapper",
  componentId: "qnnoe2-0"
})(["padding-top:", ";user-select:none;"], _designparams.spacing.huge);

var DateWrapper = _styledComponents.default.div.withConfig({
  displayName: "DatePicker__DateWrapper",
  componentId: "qnnoe2-1"
})(["width:100%;background-color:", ";display:flex;flex-wrap:wrap;justify-content:space-evenly;border-bottom:2px solid ", ";"], (_ref) => {
  var {
    theme
  } = _ref;
  return theme.color.background01();
}, (_ref2) => {
  var {
    theme
  } = _ref2;
  return theme.color.background00();
});

var DayPicker = _styledComponents.default.div.withConfig({
  displayName: "DatePicker__DayPicker",
  componentId: "qnnoe2-2"
})(["width:100%;height:216px;background-color:", ";display:flex;flex-wrap:wrap;justify-content:space-evenly;"], (_ref3) => {
  var {
    theme
  } = _ref3;
  return theme.color.background01();
});

var DateButtonContainer = _styledComponents.default.div.withConfig({
  displayName: "DatePicker__DateButtonContainer",
  componentId: "qnnoe2-3"
})(["text-align:center;width:14%;"]);

var WeekdayTypo = (0, _styledComponents.default)(_Typography.Typography).withConfig({
  displayName: "DatePicker__WeekdayTypo",
  componentId: "qnnoe2-4"
})(["text-align:center;width:14%;color:", ";margin:", " 0;font-size:", ";"], (_ref4) => {
  var {
    theme
  } = _ref4;
  return theme.color.text03();
}, _designparams.spacing.medium, _theme.font.size.large);

var MonthPicker = _styledComponents.default.div.withConfig({
  displayName: "DatePicker__MonthPicker",
  componentId: "qnnoe2-5"
})(["display:flex;align-items:center;justify-content:space-between;margin-bottom:", ";"], _designparams.spacing.medium);

var YearPicker = _styledComponents.default.div.withConfig({
  displayName: "DatePicker__YearPicker",
  componentId: "qnnoe2-6"
})(["margin-top:", ";display:flex;align-items:center;justify-content:center;width:100%;"], _designparams.spacing.medium);

var MonthYearLabel = (0, _styledComponents.default)(_Typography.Typography).withConfig({
  displayName: "DatePicker__MonthYearLabel",
  componentId: "qnnoe2-7"
})(["font-size:", ";"], _theme.font.size.large);
var DateButton = (0, _styledComponents.default)(_Button.NativeButton).withConfig({
  displayName: "DatePicker__DateButton",
  componentId: "qnnoe2-8"
})(["border-radius:", ";width:36px;height:36px;min-width:unset;padding:0;box-shadow:initial;:focus{border:initial;box-shadow:initial;}"], _designparams.shape.radius.circle);
var DateButtonLabel = (0, _styledComponents.default)(_Typography.Typography).withConfig({
  displayName: "DatePicker__DateButtonLabel",
  componentId: "qnnoe2-9"
})(["", ""], (_ref5) => {
  var {
    theme,
    selected
  } = _ref5;

  if (selected) {
    return (0, _styledComponents.css)(["color:", ";"], theme.color.text00());
  }

  return (0, _styledComponents.css)(["color:", ";"], theme.color.text03());
});
/**
 * Gets all days for given month and year.
 */

var getDaysInMonth = (year, month) => {
  var date = new Date(year, month, 1);
  var days = [];

  while (date.getMonth() === month) {
    days.push(new Date(date));
    date.setDate(date.getDate() + 1);
  }

  return days;
};
/**
 * Gets weekday labels for the calendar.
 * @param lang locale string
 */


var getWeekDays = lang => {
  var date = new Date('1/5/1970'); // Monday Jan 5th 1970 - starting at a known Monday

  var days = [];

  for (var i = 0; i < 7; i++) {
    days.push(date.toLocaleString(lang, {
      weekday: 'short'
    }));
    date.setDate(date.getDate() + 1);
  }

  return days;
};

/**
 * DatePicker
 *
 * Modal component that allows users to choose
 * date, time and time zone setting
 */
var DatePicker = (_ref6) => {
  var {
    date,
    onChange,
    lang = 'en'
  } = _ref6;
  var days = (0, _react.useMemo)(() => getDaysInMonth(date.getFullYear(), date.getMonth()), [date]);
  var firstDayOfMonth = (0, _react.useMemo)(() => days[0].getDay() === 0 ? 6 : days[0].getDay() - 1, [days]);
  var lastDayOfMonth = (0, _react.useMemo)(() => days[days.length - 1].getDay() === 0 ? 7 : days[days.length - 1].getDay(), [days]);
  var navigateMonth = (0, _react.useCallback)(n => {
    var newDate = new Date(date);
    var checkValue = newDate.getMonth();
    newDate.setMonth(checkValue + n); // If changing month on last date of the month you might end up
    // in either the same month or one month ahead, step back date
    // until we have the correct month.

    while (newDate.getMonth() === checkValue || newDate.getMonth() === checkValue + 2) {
      newDate.setDate(newDate.getDate() - 1);
    }

    onChange(newDate);
  }, [date, onChange]);
  var onNextMonthClick = (0, _react.useCallback)(() => navigateMonth(1), [navigateMonth]);
  var onPreviousMonthClick = (0, _react.useCallback)(() => navigateMonth(-1), [navigateMonth]);
  var onDateClick = (0, _react.useCallback)(e => {
    var newDate = new Date(date);
    newDate.setDate(Number(e.currentTarget.innerText));
    onChange(newDate);
  }, [date, onChange]);
  var navigateYear = (0, _react.useCallback)(n => {
    var newDate = new Date(date);
    newDate.setFullYear(newDate.getFullYear() + n);
    onChange(newDate);
  }, [date, onChange]);
  var onNextYearClick = (0, _react.useCallback)(() => navigateYear(1), [navigateYear]);
  var onPreviousYearClick = (0, _react.useCallback)(() => navigateYear(-1), [navigateYear]);
  var weekdays = (0, _react.useMemo)(() => getWeekDays(lang), [lang]);
  return /*#__PURE__*/_react.default.createElement(DatePickerWrapper, null, /*#__PURE__*/_react.default.createElement(MonthPicker, null, /*#__PURE__*/_react.default.createElement(_Button.IconButton, {
    onClick: onPreviousMonthClick,
    icon: _practicalReactComponentsIcons.ArrowLeftIcon,
    variant: "secondary"
  }), /*#__PURE__*/_react.default.createElement(MonthYearLabel, {
    variant: "default-text"
  }, date.toLocaleString(lang, {
    month: 'long'
  })), /*#__PURE__*/_react.default.createElement(_Button.IconButton, {
    onClick: onNextMonthClick,
    icon: _practicalReactComponentsIcons.ArrowRightIcon,
    variant: "secondary"
  })), /*#__PURE__*/_react.default.createElement(DateWrapper, null, weekdays.map(weekday => /*#__PURE__*/_react.default.createElement(WeekdayTypo, {
    key: weekday,
    variant: "default-text"
  }, weekday))), /*#__PURE__*/_react.default.createElement(DayPicker, null, Array(firstDayOfMonth).fill(0).map((_, i) => /*#__PURE__*/_react.default.createElement(DateButtonContainer, {
    key: i
  })), days.map(dayObj => {
    var day = dayObj.getDate();
    var selected = day === date.getDate();
    return /*#__PURE__*/_react.default.createElement(DateButtonContainer, {
      key: day
    }, /*#__PURE__*/_react.default.createElement(DateButton, {
      key: day,
      variant: selected ? 'primary' : 'secondary',
      onClick: onDateClick,
      accent: false,
      visibleFocus: false
    }, /*#__PURE__*/_react.default.createElement(DateButtonLabel, {
      selected: selected,
      variant: "default-text"
    }, day.toString())));
  }), Array(7 - lastDayOfMonth).fill(0).map((_, i) => /*#__PURE__*/_react.default.createElement(DateButtonContainer, {
    key: i
  }))), /*#__PURE__*/_react.default.createElement(YearPicker, null, /*#__PURE__*/_react.default.createElement(_Button.IconButton, {
    onClick: onPreviousYearClick,
    icon: _practicalReactComponentsIcons.ArrowLeftIcon,
    variant: "secondary"
  }), /*#__PURE__*/_react.default.createElement(MonthYearLabel, {
    variant: "default-text"
  }, date.getFullYear().toString()), /*#__PURE__*/_react.default.createElement(_Button.IconButton, {
    onClick: onNextYearClick,
    icon: _practicalReactComponentsIcons.ArrowRightIcon,
    variant: "secondary"
  })));
};

exports.DatePicker = DatePicker;