import React from 'react';
declare type BaseElement = HTMLInputElement;
declare type BaseProps = React.InputHTMLAttributes<BaseElement>;
export declare type NumberInputType = number | '';
export declare type InputChangeHandler = React.ChangeEventHandler<BaseElement>;
export declare type InputValueChangeHandler<T> = (value: T) => void;
export declare type TextInputWidth = 'small' | 'medium' | 'large' | 'full';
export declare type TextInputCredentialsType = 'username' | 'current-password' | 'new-password';
export declare type InputType = 'text' | 'number';
declare type ErrorVariant = 'text' | 'icon';
interface BaseInputProps<T extends string | NumberInputType> extends BaseProps {
    /**
     * Specifies the name of an input element.
     */
    readonly name?: BaseProps['name'];
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * The value of the input element.
     */
    readonly value: T;
    /**
     * Native change handler that can be used by formik etc.
     */
    readonly onChange?: InputChangeHandler;
    /**
     * Smooth typed value change handler.
     */
    readonly onValueChange?: InputValueChangeHandler<T>;
    /**
     * Executes an action when the Enter key is pressed.
     */
    readonly onPressEnter?: VoidFunction;
    /**
     * Executes an action when the Esc key is pressed.
     */
    readonly onPressEscape?: VoidFunction;
    /**
     * Changes the width of the textbox area.
     */
    readonly width?: TextInputWidth;
    /**
     * Adds error message to TextInput.
     */
    readonly error?: string;
    /**
     * Error message variant.
     *
     * Default: `text`
     */
    readonly errorVariant?: ErrorVariant;
    /**
     * Can be used to set React ref to the input element
     */
    readonly inputRef?: React.RefObject<BaseElement>;
    /**
     * Override theme's default setting for `compact` if set.
  
     */
    readonly compact?: boolean;
}
export interface TextInputProps extends BaseInputProps<string> {
}
export declare const TextInput: React.FC<TextInputProps>;
export interface NumberInputProps extends BaseInputProps<NumberInputType> {
}
export declare const NumberInput: React.FC<NumberInputProps>;
export interface TextInputCredentialsProps extends BaseInputProps<string> {
    readonly type: TextInputCredentialsType;
}
export declare const TextInputCredentials: React.FC<TextInputCredentialsProps>;
export declare const TextInputField: React.FunctionComponent<import("../utils/withField").FieldProps & TextInputProps>;
export declare const NumberInputField: React.FunctionComponent<import("../utils/withField").FieldProps & NumberInputProps>;
export declare const TextInputCredentialsField: React.FunctionComponent<import("../utils/withField").FieldProps & TextInputCredentialsProps>;
export {};
