import React, { ReactNode } from 'react';
import { PopOverProps } from '../PopOver';
declare type BaseElement = HTMLDivElement;
declare type BaseProps = React.HTMLAttributes<BaseElement>;
declare type BaseButtonElement = HTMLButtonElement;
declare type BaseButtonProps = React.HTMLAttributes<BaseButtonElement>;
export declare const MenuButtonIconContainer: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
export declare const MenuButtonIcon: import("styled-components").StyledComponent<React.FunctionComponent<import("../Icon").IconProps>, import("styled-components").DefaultTheme, {
    className: "sc-ButtonIcon";
}, "className">;
export declare const MenuButtonHalo: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {}, never>;
export declare const BaseMenuItem: import("styled-components").StyledComponent<"div", import("styled-components").DefaultTheme, {
    readonly disabled?: boolean | undefined;
    readonly keyboardSelect?: boolean | undefined;
}, never>;
declare type ButtonClickHandler = React.MouseEventHandler<HTMLButtonElement>;
interface MenuButtonProps extends BaseButtonProps {
    /**
     * If `true`, the button will be disabled.
     */
    readonly disabled?: boolean;
    /**
     * Specifies the name for a <button> element.
     * It is used to reference form-data after the form has been submitted,
     * or to reference the element in a JavaScript.
     */
    readonly name?: string;
    /**
     * Executes a JavaScript when a user click the button.
     */
    readonly onClick: ButtonClickHandler;
    /**
     * `class` to be passed to the component.
     */
    readonly className?: string;
    /**
     * The title attribute specifies extra information about an element.
     */
    readonly title?: string;
}
export declare const MenuButton: React.ForwardRefExoticComponent<MenuButtonProps & React.RefAttributes<HTMLButtonElement>>;
/**
 * Add an escape listener to the actual rendered menu.
 */
interface MenuWrapperProps extends BaseProps {
    readonly onClose: () => void;
    /**
     * `class` to be passed to the component.
     */
    readonly className?: string;
}
export declare const MenuWrapper: React.FunctionComponent<MenuWrapperProps>;
export interface BaseItemProps {
    readonly component: ReactNode;
    readonly onClick: () => void;
    readonly disabled?: boolean;
    readonly keyboardSelect?: boolean;
}
export interface BaseMenuProps extends Omit<PopOverProps, 'anchorEl'> {
    /**
     * React element that will appear as menu button
     */
    readonly button: ReactNode;
    /**
     * Aligns the menu either left or right.
     */
    readonly align?: 'left' | 'right';
    /**
     * Disabled
     */
    readonly disabled?: boolean;
    /**
     * Components to render
     */
    readonly components: ReadonlyArray<BaseItemProps>;
}
/**
 * BaseMenu
 *
 * Anchor with a button that toggles a menu when you click the button.
 * When pressing the escape key, the menu is closed.
 */
export declare const BaseMenu: React.NamedExoticComponent<BaseMenuProps>;
export {};
