import React from 'react';
declare type BaseElement = HTMLDivElement;
declare type BaseProps = React.HTMLAttributes<BaseElement>;
export interface SliderProps extends BaseProps {
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * Specifies default value between min and max value.
     */
    readonly value: number;
    /**
     * Specifies minimum value of the slider.
     */
    readonly min?: number;
    /**
     * Specifies maximum value of the slider.
     */
    readonly max?: number;
    /**
     * Executes a JavaScript when a user changes the value.
     */
    readonly handleChange: (value: number) => void;
    /**
     * If `true`, the slider will be disabled.
     */
    readonly disabled?: boolean;
}
/**
 * Slider component
 *
 * A horizontal track with a knob that can be moved
 * forward and backward. When the knob is pressed,
 * no transitions are applied, but when the track itself
 * is pressed, the knob jumps to the new position with
 * an animation.
 */
/**
 * TODO: according to UX, need to add `variant` property to have style `dashed`
 */
export declare const Slider: React.FC<SliderProps>;
export declare const SliderField: React.FunctionComponent<import("../utils").FieldProps & SliderProps>;
export {};
