/**
 * Theme definitions for styled components
 */
declare type RGB = readonly [number, number, number];
/**
 * Create a color that is a shade of grey
 * @param brightness The level of white in grey (0 = black, 100 = white)
 */
export declare const grey: (brightness?: number) => RGB;
/**
 * Convenience wrappers for allowing any color to
 * have an alpha channel.
 */
export declare type CSSColor = (a?: number) => string;
export declare const createCSSColor: ([r, g, b]: RGB) => CSSColor;
export declare const getHexValue: (rgb: string) => string;
/**
 * Color palette
 */
export declare const basePalette: {
    black: CSSColor;
    grey16: CSSColor;
    grey20: CSSColor;
    grey24: CSSColor;
    grey32: CSSColor;
    grey40: CSSColor;
    grey48: CSSColor;
    grey64: CSSColor;
    grey72: CSSColor;
    grey80: CSSColor;
    grey88: CSSColor;
    grey90: CSSColor;
    grey92: CSSColor;
    grey94: CSSColor;
    grey95: CSSColor;
    grey96: CSSColor;
    grey97: CSSColor;
    grey98: CSSColor;
    grey99: CSSColor;
    white: CSSColor;
    transparent: () => string;
};
export declare type ColorWeight = '50' | '100' | '200' | '300' | '400' | '500' | '600' | '700' | '800' | '900';
export declare type ColorSpecialWeight = 'A100' | 'A200' | 'A400' | 'A700';
export declare type ColorBaseName = 'red' | 'pink' | 'purple' | 'deepPurple' | 'indigo' | 'blue' | 'lightBlue' | 'cyan' | 'teal' | 'green' | 'lightGreen' | 'lime' | 'yellow' | 'amber' | 'orange' | 'deepOrange';
export declare type SimpleColorBaseName = 'brown' | 'grey' | 'blueGrey';
export declare type ColorName = `${ColorBaseName}${ColorWeight | ColorSpecialWeight}` | `${SimpleColorBaseName}${ColorWeight}` | keyof typeof basePalette;
/** Material palette. See https://material.io/resources/color */
export declare const palette: Record<ColorName, CSSColor>;
export {};
